<?php
/**
 * Plugin Name: LatePoint Addon - Payments Flutterwave
 * Plugin URI:  https://latepoint.com/
 * Description: LatePoint addon for payments via flutterwave
 * Version:     1.0.2
 * Author:      LatePoint
 * Author URI:  https://latepoint.com/
 * Text Domain: latepoint-payments-flutterwave
 * Domain Path: /languages
 */

if ( ! defined( 'ABSPATH' ) ) {
  exit; // Exit if accessed directly.
}

// If no LatePoint class exists - exit, because LatePoint plugin is required for this addon

if ( ! class_exists( 'LatePointPaymentsFlutterwave' ) ) :

/**
 * Main Addon Class.
 *
 */

class LatePointPaymentsFlutterwave {

  /**
   * Addon version.
   *
   */
  public $version = '1.0.2';
  public $db_version = '1.0.0';
  public $addon_name = 'latepoint-payments-flutterwave';

  public $processor_code = 'flutterwave';


  /**
   * LatePoint Constructor.
   */
  public function __construct() {
    $this->define_constants();
    $this->init_hooks();
  }

  /**
   * Define LatePoint Constants.
   */
  public function define_constants() {
    // $this->define( 'LATEPOINT_ADDON_EXAMPLE_CONSTANT', 'example' );
  }


  public static function public_stylesheets() {
    return plugin_dir_url( __FILE__ ) . 'public/stylesheets/';
  }

  public static function public_javascripts() {
    return plugin_dir_url( __FILE__ ) . 'public/javascripts/';
  }

  public static function images_url() {
    return plugin_dir_url( __FILE__ ) . 'public/images/';
  }

  /**
   * Define constant if not already set.
   *
   */
  public function define( $name, $value ) {
    if ( ! defined( $name ) ) {
      define( $name, $value );
    }
  }

  /**
   * Include required core files used in admin and on the frontend.
   */
  public function includes() {

    // CONTROLLERS
    include_once( dirname( __FILE__ ) . '/lib/controllers/payments_flutterwave_controller.php' );

    // HELPERS
    include_once( dirname( __FILE__ ) . '/lib/helpers/payments_flutterwave_helper.php' );

    // MODELS
    // include_once(dirname( __FILE__ ) . '/lib/models/example_model.php' );

  }


  public function init_hooks(){
    // Hook into the latepoint initialization action and initialize this addon
    add_action('latepoint_init', [$this, 'latepoint_init']);

    // Include additional helpers and controllers 
    add_action('latepoint_includes', [$this, 'includes']);

    // Modify a list of installed add-ons
    add_filter('latepoint_installed_addons', [$this, 'register_addon']);

    // Register flutterwave as a payment processor
    add_filter('latepoint_payment_processors', [$this, 'register_payment_processor'], 10, 2);
    // Register flutterwave's available payment methods
    add_filter('latepoint_all_payment_methods', [$this, 'register_payment_methods']);
    // Add payment methods to a list of enabled methods for the front-end, if processor is turned on in settings
    add_filter('latepoint_enabled_payment_methods', [$this, 'register_enabled_payment_methods']);

    // add settings fields for the payment processor
    add_action('latepoint_payment_processor_settings',[$this, 'add_settings_fields'], 10);

    // encrypt sensitive fields
    add_filter('latepoint_encrypted_settings', [$this, 'add_encrypted_settings']);

    // pass variables to JS frontend
    add_filter('latepoint_localized_vars_front', [$this, 'localized_vars_for_front']);

    // Add a link to the side menu

    // Include JS and CSS for the admin panel
    add_action('latepoint_admin_enqueue_scripts', [$this, 'load_admin_scripts_and_styles']);

    // Include JS and CSS for the frontend site
    add_action('latepoint_wp_enqueue_scripts', [$this, 'load_front_scripts_and_styles']);

    // All other hooks can go here, for a list of available hoooks go to: http://wpdocs.latepoint.com/list-of-latepoint-hooks-actions-and-filters/
    // add_action('EXAMPLE_HOOK', [$this, 'EXAMPLE_FUNCTION']);

    // init the addon
    add_action( 'init', array( $this, 'init' ), 0 );

    register_activation_hook(__FILE__, [$this, 'on_activate']);
    register_deactivation_hook(__FILE__, [$this, 'on_deactivate']);

    // hook into payment processing
    add_filter('latepoint_process_payment_for_booking', [$this, 'process_payment'], 10, 3);

  }


  public function process_payment($result, $booking, $customer){
    if(OsPaymentsHelper::is_payment_processor_enabled($this->processor_code)){
      switch($booking->payment_method){
        case 'inline_checkout':
          if($booking->payment_token){
            $transaction = OsPaymentsFlutterwaveHelper::retrieve_transaction($booking->payment_token);
            if(!is_wp_error($transaction)){
              if($transaction->status == 'successful'){
                $result['status'] = LATEPOINT_STATUS_SUCCESS;
                $result['charge_id'] = $transaction->id;
                $result['processor'] = $this->processor_code;
                $result['funds_status'] = LATEPOINT_TRANSACTION_FUNDS_STATUS_CAPTURED;
              }else{
                $result['status'] = LATEPOINT_STATUS_ERROR;
                $result['message'] = __('Payment Error', 'latepoint-payments-flutterwave');
                $booking->add_error('payment_error', $result['message']);
                $booking->add_error('send_to_step', $result['message'], 'payment');
              }
            }else{
              $result['status'] = LATEPOINT_STATUS_ERROR;
              $result['message'] = $transaction->getMessage();
              $booking->add_error('payment_error', $result['message']);
              $booking->add_error('send_to_step', $result['message'], 'payment');
            }
          }else{
            $result['status'] = LATEPOINT_STATUS_ERROR;
            $result['message'] = __('Payment Error KSF9834', 'latepoint-payments-flutterwave');
            $booking->add_error('payment_error', $result['message']);
          }
        break;
      }
    }
    return $result;
  }


  public function add_encrypted_settings($encrypted_settings){
    $encrypted_settings[] = 'flutterwave_secret_key';
    return $encrypted_settings;
  }



  public function localized_vars_for_front($localized_vars){
    if(OsPaymentsHelper::is_payment_processor_enabled($this->processor_code)){
      $localized_vars['flutterwave_key'] = OsPaymentsFlutterwaveHelper::get_publishable_key();
      $localized_vars['is_flutterwave_active'] = true;
      $localized_vars['flutterwave_payment_options_route'] = OsRouterHelper::build_route_name('payments_flutterwave', 'get_payment_options');
    }else{
      $localized_vars['is_flutterwave_active'] = false;

    }
    return $localized_vars;
  }


  public function add_settings_fields($processor_code){
    if($processor_code != $this->processor_code) return false; ?>

    <div class="sub-section-row">
      <div class="sub-section-label">
	      <h3><?php _e('API Keys', 'latepoint-payments-flutterwave'); ?></h3>
      </div>
      <div class="sub-section-content">
	      <div class="os-row">
	        <div class="os-col-6">
	          <?php echo OsFormHelper::text_field('settings[flutterwave_publishable_key]', __('Public Key', 'latepoint-payments-flutterwave'), OsPaymentsFlutterwaveHelper::get_publishable_key(), ['theme' => 'bordered']); ?>
	        </div>
	        <div class="os-col-6">
	          <?php echo OsFormHelper::password_field('settings[flutterwave_secret_key]', __('Secret Key', 'latepoint-payments-flutterwave'), OsPaymentsFlutterwaveHelper::get_secret_key(), ['theme' => 'bordered']); ?>
	        </div>
	      </div>
      </div>
    </div>
    <div class="sub-section-row">
      <div class="sub-section-label">
	      <h3><?php _e('Currency Settings', 'latepoint-payments-flutterwave'); ?></h3>
      </div>
      <div class="sub-section-content">
	      <div class="os-row">
	        <div class="os-col-6">
	          <?php echo OsFormHelper::select_field('settings[flutterwave_country_code]', __('Country', 'latepoint-payments-flutterwave'), OsPaymentsFlutterwaveHelper::load_countries_list(), OsSettingsHelper::get_settings_value('flutterwave_country_code', 'NG')); ?>
	        </div>
	        <div class="os-col-6">
	          <?php echo OsFormHelper::select_field('settings[flutterwave_currency_iso_code]', __('Currency', 'latepoint-payments-flutterwave'), OsPaymentsFlutterwaveHelper::load_currencies_list(), OsSettingsHelper::get_settings_value('flutterwave_currency_iso_code', 'NGN')); ?>
	        </div>
	      </div>
      </div>
    </div>
    <div class="sub-section-row">
      <div class="sub-section-label">
	      <h3><?php _e('Business Settings', 'latepoint-payments-flutterwave'); ?></h3>
      </div>
      <div class="sub-section-content">
      <div class="os-row mb-1">
        <div class="os-col-12">
          <?php echo OsFormHelper::text_field('settings[flutterwave_company_name]', __('Your Company Name', 'latepoint-payments-flutterwave'), OsSettingsHelper::get_settings_value('flutterwave_company_name'), ['theme' => 'bordered']); ?>
        </div>
      </div>
      <div class="os-row">
        <div class="os-col-12">
          <?php echo OsFormHelper::media_uploader_field('settings[flutterwave_logo_image_id]', 0, __('Logo for Payment Modal', 'latepoint-payments-flutterwave'), __('Remove Logo', 'latepoint-payments-flutterwave'), OsSettingsHelper::get_settings_value('flutterwave_logo_image_id')); ?>
        </div>
      </div>
      </div>
    </div>
    <?php
  }

  // Payment method for the processor
  public function get_supported_payment_methods(){
    return [
            'inline_checkout' => [
                        'name' => __('Inline Checkout', 'latepoint-payments-flutterwave'), 
                        'label' => __('Inline Checkout', 'latepoint-payments-flutterwave'), 
                        'image_url' => LATEPOINT_IMAGES_URL.'payment_cards.png',
                        'code' => 'inline_checkout',
                        'time_type' => 'now'
                      ]
          ];
  }

  // register payment processor
  public function register_payment_processor($payment_processors, $enabled_only){
    $payment_processors[$this->processor_code] = ['code' => $this->processor_code, 'name' => __('Flutterwave', 'latepoint-payments-flutterwave'), 'image_url' => $this->images_url().'processor-logo.png'];
    return $payment_processors;
  }

  // adds payment method to payment settings
  public function register_payment_methods($payment_methods){
    $payment_methods = array_merge($payment_methods, $this->get_supported_payment_methods());
    return $payment_methods;
  }

  // enables payment methods if the processor is turned on
  public function register_enabled_payment_methods($enabled_payment_methods){
    // check if payment processor is enabled in settings
    if(OsPaymentsHelper::is_payment_processor_enabled($this->processor_code)){
      $enabled_payment_methods = array_merge($enabled_payment_methods, $this->get_supported_payment_methods());
    }
    return $enabled_payment_methods;
  }



  // Loads addon specific javascript and stylesheets for frontend site
  public function load_front_scripts_and_styles(){
    // Stylesheets
    wp_enqueue_style( 'latepoint-payments-flutterwave-front', $this->public_stylesheets() . 'latepoint-payments-flutterwave-front.css', false, $this->version );

    // Javascripts
    wp_enqueue_script( 'flutterwave-checkout', 'https://checkout.flutterwave.com/v3.js', false, null );
    wp_enqueue_script( 'latepoint-payments-flutterwave-front',  $this->public_javascripts() . 'latepoint-payments-flutterwave-front.js', array('jquery', 'flutterwave-checkout', 'latepoint-main-front'), $this->version );

  }

  // Loads addon specific javascript and stylesheets for admin (wp-admin)
  public function load_admin_scripts_and_styles($localized_vars){
    // Stylesheets
    wp_enqueue_style( 'latepoint-payments-flutterwave-admin', $this->public_stylesheets() . 'latepoint-payments-flutterwave-admin.css', false, $this->version );

    // Javascripts
  }


  /**
   * Init addon when WordPress Initialises.
   */
  public function init() {
    // Set up localisation.
    $this->load_plugin_textdomain();
  }

  public function latepoint_init(){
    LatePoint\Cerber\Router::init_addon();
  }


  // set text domain for the addon, for string translations to work
  public function load_plugin_textdomain() {
    load_plugin_textdomain('latepoint-payments-flutterwave', false, dirname(plugin_basename(__FILE__)) . '/languages');
  }


  public function on_deactivate(){
  }

  public function on_activate(){
    do_action('latepoint_on_addon_activate', $this->addon_name, $this->version);
  }

  public function register_addon($installed_addons){
    $installed_addons[] = ['name' => $this->addon_name, 'db_version' => $this->db_version, 'version' => $this->version];
    return $installed_addons;
  }



}

endif;

if ( in_array( 'latepoint/latepoint.php', get_option( 'active_plugins', array() ) )  || array_key_exists('latepoint/latepoint.php', get_site_option('active_sitewide_plugins', array())) ) {
  $LATEPOINT_ADDON_PAYMENTS_FLUTTERWAVE = new LatePointPaymentsFlutterwave();
}
$latepoint_session_salt = 'NmQ3OTBhMTItYjY5ZS00ZGFlLTg5ODMtNTlkYzVjZTM4MTVi';
