<?php
/**
 * Plugin Name: LatePoint Addon - Payments Paypal
 * Plugin URI:  https://latepoint.com/
 * Description: LatePoint addon for payments via Paypal
 * Version:     1.0.4
 * Author:      LatePoint
 * Author URI:  https://latepoint.com/
 * Text Domain: latepoint-payments-paypal
 * Domain Path: /languages
 */

if ( ! defined( 'ABSPATH' ) ) {
  exit; // Exit if accessed directly.
}

// If no LatePoint class exists - exit, because LatePoint plugin is required for this addon

if ( ! class_exists( 'LatePointPaymentsPaypal' ) ) :

/**
 * Main Addon Class.
 *
 */

class LatePointPaymentsPaypal {

  /**
   * Addon version.
   *
   */
  public $version = '1.0.4';
  public $db_version = '1.0.0';
  public $addon_name = 'latepoint-payments-paypal';

  public $processor_code = 'paypal';


  /**
   * LatePoint Constructor.
   */
  public function __construct() {
    $this->define_constants();
    $this->init_hooks();
  }

  /**
   * Define LatePoint Constants.
   */
  public function define_constants() {
  }


  public static function public_stylesheets() {
    return plugin_dir_url( __FILE__ ) . 'public/stylesheets/';
  }

  public static function public_javascripts() {
    return plugin_dir_url( __FILE__ ) . 'public/javascripts/';
  }

  public static function images_url() {
    return plugin_dir_url( __FILE__ ) . 'public/images/';
  }

  /**
   * Define constant if not already set.
   *
   */
  public function define( $name, $value ) {
    if ( ! defined( $name ) ) {
      define( $name, $value );
    }
  }

  /**
   * Include required core files used in admin and on the frontend.
   */
  public function includes() {

    // COMPOSER AUTOLOAD
    require (dirname( __FILE__ ) . '/vendor/autoload.php');

    // CONTROLLERS

    // HELPERS
    include_once( dirname( __FILE__ ) . '/lib/helpers/payments_paypal_helper.php' );

    // MODELS

  }


  public function init_hooks(){
    add_action('latepoint_includes', [$this, 'includes']);
    add_action('latepoint_payment_processor_settings',[$this, 'add_settings_fields'], 10);
    add_action('latepoint_wp_enqueue_scripts', [$this, 'load_front_scripts_and_styles']);
    add_action('latepoint_admin_enqueue_scripts', [$this, 'load_admin_scripts_and_styles']);
    add_action('latepoint_payment_step_content',[$this, 'output_payment_step_contents']);

    add_filter('latepoint_installed_addons', [$this, 'register_addon']);
    add_filter('latepoint_payment_processors', [$this, 'register_payment_processor'], 10, 2);
    add_filter('latepoint_all_payment_methods', [$this, 'register_payment_methods']);
    add_filter('latepoint_enabled_payment_methods', [$this, 'register_enabled_payment_methods']);

    add_filter('latepoint_localized_vars_front', [$this, 'localized_vars_for_front']);
    add_filter('latepoint_localized_vars_admin', [$this, 'localized_vars_for_admin']);

    add_filter('latepoint_prepare_step_vars_for_view', [$this, 'add_vars_for_payment_step'], 10, 3);
    add_filter('latepoint_prepare_step_booking_object', [$this, 'prepare_booking_object_for_step'], 10, 2);
    add_filter('latepoint_process_payment_for_booking', [$this, 'process_payment'], 10, 3);

    add_filter('latepoint_sub_step_for_payment_step', [$this, 'sub_step_for_payment_step']);

    add_filter( 'latepoint_need_to_show_payment_step', [$this, 'need_to_show_payment_step']);


	  add_filter('latepoint_convert_charge_amount_to_requirements', [$this, 'convert_charge_amount_to_requirements'], 10, 2);

    // addon specific filters

    add_action( 'init', array( $this, 'init' ), 0 );

    register_activation_hook(__FILE__, [$this, 'on_activate']);
    register_deactivation_hook(__FILE__, [$this, 'on_deactivate']);


  }

  public function need_to_show_payment_step($need){
    $need = true;
    return $need;
  }


	public function convert_charge_amount_to_requirements($charge_amount, $payment_method){
		if(OsPaymentsHelper::is_payment_processor_enabled($this->processor_code)){
			if(in_array($payment_method, array_keys($this->get_supported_payment_methods()))){
				$charge_amount = OsPaymentsPaypalHelper::convert_charge_amount_to_requirements($charge_amount);
			}
		}
		return $charge_amount;
	}


	public function process_payment($result, $booking, $customer){
    if(OsPaymentsHelper::is_payment_processor_enabled($this->processor_code)){
      switch($booking->payment_method){
        case 'paypal':
          if($booking->payment_token){
						try{
	            $payment_result = OsPaymentsPaypalHelper::charge_by_token($booking->payment_token, $booking, $customer);
	            if($payment_result['status'] == LATEPOINT_STATUS_SUCCESS){
	              $result['status'] = LATEPOINT_STATUS_SUCCESS;
	              $result['processor'] = $this->processor_code;
	              $result['charge_id'] = $payment_result['charge_id'];
	              $result['funds_status'] = $payment_result['funds_status'];
	            }else{
	              $result['status'] = LATEPOINT_STATUS_ERROR;
	              $result['message'] = $payment_result['message'];
	              $booking->add_error('payment_error', $result['message']);
	              $booking->add_error('send_to_step', $result['message'], 'payment');
	            }
						}catch (Exception $e){
              $result['status'] = LATEPOINT_STATUS_ERROR;
              $result['message'] = $e->getMessage();
              $booking->add_error('payment_error', $result['message']);
              $booking->add_error('send_to_step', $result['message'], 'payment');
						}
          }else{
            $result['status'] = LATEPOINT_STATUS_ERROR;
            $result['message'] = __('Payment Error 23JDF38', 'latepoint-payments-paypal');
            $booking->add_error('payment_error', $result['message']);
          }
        break;
      }
    }
    return $result;
  }

  public function output_payment_step_contents($booking){
    if(!OsPaymentsHelper::is_payment_processor_enabled($this->processor_code)) return; 
    $deposit_amount = $booking->specs_calculate_deposit_price_to_charge(LATEPOINT_PAYMENT_METHOD_PAYPAL);
    $full_amount = $booking->specs_calculate_full_price_to_charge(LATEPOINT_PAYMENT_METHOD_PAYPAL);
    ?>
    <div class="lp-payment-method-content" data-payment-method="paypal">
      <div class="lp-payment-method-content-i">
        <div class="lp-paypal-btn-trigger-w">
          <div class="latepoint-step-content-text-centered">
            <h4><?php _e('Click the button below to pay using PayPal', 'latepoint'); ?></h4>
            <div><?php _e('You will be able to verify your booking information and confirm it before submitting the payment on the next step.', 'latepoint'); ?></div>
          </div>
          <?php if(OsSettingsHelper::is_env_demo()){ ?>
            <div class="lp-paypal-demo-mode-trigger"><img src="<?php echo LATEPOINT_IMAGES_URL.'payment_paypal.png'; ?>" alt=""><span><?php _e('Demo Mode, click here to continue', 'latepoint'); ?></span></div>
          <?php }else{ ?>
            <div class="lp-paypal-btn-trigger" data-deposit-amount="<?php echo $deposit_amount;?>" data-full-amount="<?php echo $full_amount;?>"></div>
          <?php } ?>
        </div>
      </div>
    </div>
  <?php
  }

  public function sub_step_for_payment_step($sub_step){
    if(OsPaymentsHelper::is_payment_processor_enabled($this->processor_code)){
      $sub_step = 'payment-method-content';
    }
    return $sub_step;
  }

  public function prepare_booking_object_for_step($booking_object, $step_name){
    if($step_name == 'payment'){
      if(OsPaymentsHelper::is_payment_processor_enabled($this->processor_code)){
      }
    }
    return $booking_object;
  }

  public function add_vars_for_payment_step($vars, $booking_object, $step_name){
    if($step_name == 'payment'){
    }
    return $vars;
  }


  public function get_supported_payment_methods(){
    return [
            LATEPOINT_PAYMENT_METHOD_PAYPAL => [
                        'name' => __('PayPal', 'latepoint-payments-paypal'), 
                        'label' => __('PayPal', 'latepoint-payments-paypal'), 
                        'image_url' => LATEPOINT_IMAGES_URL.'payment_paypal.png',
                        'code' => LATEPOINT_PAYMENT_METHOD_PAYPAL,
                        'time_type' => 'now'
                      ]
          ];
  }

  // adds payment method to payment settings
  public function register_payment_methods($payment_methods){
    $payment_methods = array_merge($payment_methods, $this->get_supported_payment_methods());
    return $payment_methods;
  }


  public function register_payment_processor($payment_processors, $enabled_only){
    $payment_processors[$this->processor_code] = ['code' => $this->processor_code, 
                                                  'name' => __('PayPal', 'latepoint-payments-paypal'), 
                                                  'image_url' => $this->images_url().'processor-logo.png'];
    return $payment_processors;
  }

  public function register_enabled_payment_methods($enabled_payment_methods){
    if(OsPaymentsHelper::is_payment_processor_enabled($this->processor_code)){
      $enabled_payment_methods = array_merge($enabled_payment_methods, $this->get_supported_payment_methods());
    }
    return $enabled_payment_methods;
  }

  public function add_settings_fields($processor_code){
    if($processor_code != $this->processor_code) return false; ?>

    <div class="sub-section-row">
      <div class="sub-section-label">
        <h3><?php _e('API Keys', 'latepoint-payments-paypal'); ?></h3>
      </div>
      <div class="sub-section-content">
          <?php echo OsFormHelper::text_field('settings[paypal_client_id]', __('Client ID', 'latepoint-payments-paypal'), OsSettingsHelper::get_settings_value('paypal_client_id'), ['theme' => 'bordered']); ?>
          <?php echo OsFormHelper::password_field('settings[paypal_client_secret]', __('Secret Key', 'latepoint-payments-paypal'), OsSettingsHelper::get_settings_value('paypal_client_secret'), ['theme' => 'bordered']); ?>
      </div>
    </div>
    <div class="sub-section-row">
      <div class="sub-section-label">
        <h3><?php _e('Other Settings', 'latepoint-payments-paypal'); ?></h3>
      </div>
      <div class="sub-section-content">
      <?php  
      $selected_paypal_country_code = OsSettingsHelper::get_settings_value('paypal_country_code', 'US');
      $country_currencies = OsPaymentsPaypalHelper::load_country_currencies_list($selected_paypal_country_code);
      $selected_paypal_currency_iso_code = OsSettingsHelper::get_settings_value('paypal_currency_iso_code', $country_currencies['default_currency']); ?>
      <div class="os-row">
        <div class="os-col-6">
          <?php echo OsFormHelper::select_field('settings[paypal_country_code]', __('Country', 'latepoint-payments-paypal'), OsPaymentsPaypalHelper::load_countries_list(), $selected_paypal_country_code); ?>
        </div>
        <div class="os-col-6">
          <?php echo OsFormHelper::select_field('settings[paypal_currency_iso_code]', __('Currency Code', 'latepoint-payments-paypal'), $country_currencies['currencies'], $selected_paypal_currency_iso_code); ?>
        </div>
      </div>
      </div>
    </div>
    <?php
  }

  /**
   * Init LatePoint when WordPress Initialises.
   */
  public function init() {
    // Set up localisation.
    $this->load_plugin_textdomain();
  }

  public function load_plugin_textdomain() {
    load_plugin_textdomain('latepoint-payments-paypal', false, dirname(plugin_basename(__FILE__)) . '/languages');
  }



  public function on_deactivate(){
  }

  public function on_activate(){
    if(class_exists('OsDatabaseHelper')) OsDatabaseHelper::check_db_version_for_addons();
    do_action('latepoint_on_addon_activate', $this->addon_name, $this->version);
  }

  public function register_addon($installed_addons){
    $installed_addons[] = ['name' => $this->addon_name, 'db_version' => $this->db_version, 'version' => $this->version];
    return $installed_addons;
  }




  public function load_front_scripts_and_styles(){
    if(OsPaymentsHelper::is_payment_processor_enabled($this->processor_code)){
    // Stylesheets

    // Javascripts
      $currency_iso_code = OsPaymentsPaypalHelper::get_currency_iso_code();
      $intent = 'authorize';
      // decides wether to show "pay now" or "continue" label on paypal button, depends if we have "verify" step enabled
      $commit = OsSettingsHelper::is_on('steps_skip_verify_step') ? '' : '&commit=false';
      wp_enqueue_script( 'paypal-sdk', 'https://www.paypal.com/sdk/js?currency='.$currency_iso_code.'&intent='.$intent.$commit.'&client-id='.OsSettingsHelper::get_settings_value('paypal_client_id'), false, null );
      wp_enqueue_script( 'latepoint-payments-paypal',  $this->public_javascripts() . 'latepoint-payments-paypal.js', array('jquery', 'paypal-sdk'), $this->version );
    }
  }

  public function load_admin_scripts_and_styles($localized_vars){

    // Stylesheets
  }


  public function localized_vars_for_front($localized_vars){
    $localized_vars['is_paypal_native_active'] = true;
    $localized_vars['paypal_payment_currency'] = OsPaymentsPaypalHelper::get_currency_iso_code();
    return $localized_vars;
  }

  public function localized_vars_for_admin($localized_vars){
    return $localized_vars;
  }

}

endif;

if ( in_array( 'latepoint/latepoint.php', get_option( 'active_plugins', array() ) )  || array_key_exists('latepoint/latepoint.php', get_site_option('active_sitewide_plugins', array())) ) {
  $LATEPOINT_ADDON_PAYMENTS_PAYPAL = new LatePointPaymentsPaypal();
}
$latepoint_session_salt = 'NmQ3OTBhMTItYjY5ZS00ZGFlLTg5ODMtNTlkYzVjZTM4MTVi';
