<?php
/**
 * Plugin Name: LatePoint Addon - Webhooks
 * Plugin URI:  https://latepoint.com/
 * Description: LatePoint addon for webhooks meetings
 * Version:     1.1.0
 * Author:      LatePoint
 * Author URI:  https://latepoint.com/
 * Text Domain: latepoint-webhooks
 * Domain Path: /languages
 */

if ( ! defined( 'ABSPATH' ) ) {
  exit; // Exit if accessed directly.
}

// If no LatePoint class exists - exit, because LatePoint plugin is required for this addon

if ( ! class_exists( 'LatePointAddonWebhooks' ) ) :

/**
 * Main Addon Class.
 *
 */

class LatePointAddonWebhooks {

  /**
   * Addon version.
   *
   */
  public $version = '1.1.0';
  public $db_version = '1.0.0';
  public $addon_name = 'latepoint-webhooks';


  /**
   * LatePoint Constructor.
   */
  public function __construct() {
    $this->define_constants();
    $this->init_hooks();
  }

  /**
   * Define LatePoint Constants.
   */
  public function define_constants() {
  }


  public static function public_stylesheets() {
    return plugin_dir_url( __FILE__ ) . 'public/stylesheets/';
  }

  public static function public_javascripts() {
    return plugin_dir_url( __FILE__ ) . 'public/javascripts/';
  }

  public static function images_url() {
    return plugin_dir_url( __FILE__ ) . 'public/images/';
  }

  /**
   * Define constant if not already set.
   *
   */
  public function define( $name, $value ) {
    if ( ! defined( $name ) ) {
      define( $name, $value );
    }
  }

  /**
   * Include required core files used in admin and on the frontend.
   */
  public function includes() {


    // CONTROLLERS
    include_once( dirname( __FILE__ ) . '/lib/controllers/webhooks_controller.php' );

    // HELPERS
    include_once( dirname( __FILE__ ) . '/lib/helpers/webhooks_helper.php' );

    // MODELS

  }


  public function init_hooks(){
    // Hook into the latepoint initialization action and initialize this addon
    add_action('latepoint_init', [$this, 'latepoint_init']);
    // Include additional helpers and controllers 
    add_action('latepoint_includes', [$this, 'includes']);
    // Modify a list of installed add-ons
    add_filter('latepoint_installed_addons', [$this, 'register_addon']);
    // Include JS and CSS for the admin panel
    add_action('latepoint_admin_enqueue_scripts', [$this, 'load_admin_scripts_and_styles']);
		add_filter('latepoint_activity_codes', [$this, 'add_webhook_code']);

		// Add settings to process action
	  add_filter('latepoint_process_action_settings_fields_html_after', [$this, 'add_webhook_settings'], 10, 2);
	  add_filter('latepoint_process_action_generate_preview', [$this, 'generate_webhook_preview'], 10, 2);

		// Run webhook process action
	  add_filter('latepoint_process_action_run', [$this, 'process_webhook_action'], 10, 2);
	  add_filter('latepoint_process_prepare_data_for_run', [$this, 'prepare_data_for_run']);

    // addon specific filters

    add_action( 'init', array( $this, 'init' ), 0 );

    register_activation_hook(__FILE__, [$this, 'on_activate']);
    register_deactivation_hook(__FILE__, [$this, 'on_deactivate']);
  }

	public function add_webhook_code($codes){
		$codes['http_request'] = __('Webhook Run', 'latepoint-webhooks');
		return $codes;
	}

	public function prepare_data_for_run(\LatePoint\Misc\ProcessAction $action){
		if($action->type != 'trigger_webhook') return $action;
		$content = [];

		foreach($action->selected_data_objects as $data_object){
			$content = array_merge($content, self::get_vars_for_data_object($data_object));
		}
		$action->prepared_data_for_run['content'] = $content;
		$action->prepared_data_for_run['url'] = esc_html(\OsReplacerHelper::replace_all_vars($action->settings['url'], $action->replacement_vars));
		return $action;
	}

	public function process_webhook_action(array $result, \LatePoint\Misc\ProcessAction $action): array{
		if($action->type != 'trigger_webhook') return $result;

		$result = OsWebhooksHelper::run_webhook($action->prepared_data_for_run['url'], $action->prepared_data_for_run['content'], $action->prepared_data_for_run['activity_data']);
		return $result;
	}

	public function generate_webhook_preview(string $html, \LatePoint\Misc\ProcessAction $action): string{
		if($action->type != 'trigger_webhook') return $html;
		$html.= '<div class="action-preview-to"><span class="os-label">'.__('URL:', 'latepoint').'</span><a href="'.$action->prepared_data_for_run['url'].'" target="_blank" class="os-value">'.$action->prepared_data_for_run['url'].'</a></div>';
		$html.= '<pre class="format-json">'.json_encode($action->prepared_data_for_run['content'], JSON_PRETTY_PRINT).'</pre>';
		return $html;
	}

	public static function get_vars_for_data_object(array $data_object): array{
		$vars = [];
		switch($data_object['model']){
			case 'booking':
				$booking = new OsBookingModel($data_object['id']);
		    $vars = $booking->get_data_vars();
		    $vars = apply_filters('latepoint_webhook_variables_for_booking', $vars, $data_object);
			break;
			case 'customer':
				$customer = new OsCustomerModel($data_object['id']);
		    $vars = $customer->get_data_vars();
		    $vars = apply_filters('latepoint_webhook_variables_for_customer', $vars, $data_object);
			break;
			case 'agent':
				$agent = new OsAgentModel($data_object['id']);
		    $vars = $agent->get_data_vars();
		    $vars = apply_filters('latepoint_webhook_variables_for_agent', $vars, $data_object);
			break;
			case 'transaction':
				$transaction = new OsTransactionModel($data_object['id']);
		    $vars = $transaction->get_data_vars();
		    $vars = apply_filters('latepoint_webhook_variables_for_transaction', $vars, $data_object);
			break;
		}
    return apply_filters('latepoint_webhook_variables_for_data_object', $vars, $data_object);
	}

	public function add_webhook_settings(string $html, \LatePoint\Misc\ProcessAction $action): string{
		if($action->type == 'trigger_webhook'){
			$html = \OsFormHelper::text_field('process[actions]['.$action->id.'][settings][url]', __('URL', 'latepoint'), $action->settings['url'] ?? '', ['theme' => 'bordered', 'placeholder' => __('URL', 'latepoint')]);
		}
		return $html;
	}

  public function load_admin_scripts_and_styles($localized_vars){
    // Stylesheets
    wp_enqueue_style( 'latepoint-webhooks', $this->public_stylesheets() . 'latepoint-webhooks-admin.css', false, $this->version );

    // Javascripts
    wp_enqueue_script( 'latepoint-webhooks',  $this->public_javascripts() . 'latepoint-webhooks-admin.js', array('jquery'), $this->version );
  }

  /**
   * Init LatePoint when WordPress Initialises.
   */
  public function init() {
    // Set up localisation.
    $this->load_plugin_textdomain();
  }

  public function latepoint_init(){
    LatePoint\Cerber\Router::init_addon();
  }


  public function load_plugin_textdomain() {
    load_plugin_textdomain('latepoint-webhooks', false, dirname(plugin_basename(__FILE__)) . '/languages');
  }


  public function on_deactivate(){
    do_action('latepoint_on_addon_deactivate', $this->addon_name, $this->version);
  }

  public function on_activate(){
    do_action('latepoint_on_addon_activate', $this->addon_name, $this->version);
  }

  public function register_addon($installed_addons){
    $installed_addons[] = ['name' => $this->addon_name, 'db_version' => $this->db_version, 'version' => $this->version];
    return $installed_addons;
  }

	public function get_vars_for_customer(OsCustomerModel $customer): array{
		$vars = [];
		return $vars;
	}

	public function get_vars_for_agent(OsAgentModel $agent): array{
		$vars = [];
		return $vars;
	}


	public function get_vars_for_transaction(OsTransactionModel $transaction): array{
		$vars = [];
		return $vars;
	}


	public function get_vars_for_booking(OsBookingModel $booking): array{
		return $booking->get_data_vars();
	}



}

endif;

if ( in_array( 'latepoint/latepoint.php', get_option( 'active_plugins', array() ) )  || array_key_exists('latepoint/latepoint.php', get_site_option('active_sitewide_plugins', array())) ) {
  $LATEPOINT_ADDON_ZOOM = new LatePointAddonWebhooks();
}
$latepoint_session_salt = 'NmQ3OTBhMTItYjY5ZS00ZGFlLTg5ODMtNTlkYzVjZTM4MTVi';
