<?php
/*
 * Copyright (c) 2023 LatePoint LLC. All rights reserved.
 */

if ( ! defined( 'ABSPATH' ) ) {
  exit; // Exit if accessed directly.
}


if ( ! class_exists( 'OsCustomerCabinetController' ) ) :


  class OsCustomerCabinetController extends OsController {

    function __construct(){
      parent::__construct();

      $this->action_access['customer'] = array_merge($this->action_access['customer'], [  'update' ]);
      $this->action_access['public'] = array_merge($this->action_access['public'], [  'logout',
                                                                                      'dashboard',
                                                                                      'login',
                                                                                      'do_login',
                                                                                      'password_reset_form',
                                                                                      'request_password_reset_token',
                                                                                      'change_password',
                                                                                      'set_account_password_on_booking_completion' ]);
      $this->views_folder = LATEPOINT_VIEWS_ABSPATH . 'customer_cabinet/';
    }

    /*
      Update profile
    */

    public function update(){
      if((OsAuthHelper::get_highest_current_user_type() == 'customer') && (OsAuthHelper::get_logged_in_customer_id() != $this->params['customer']['id'])){
        if($this->get_return_format() == 'json'){
          $this->send_json(array('status' => LATEPOINT_STATUS_ERROR, 'message' => 'Customer Not Authorized'));
        }else{
          echo "Customer Not Authorized";
        }
        exit;
      }
      if(filter_var($this->params['customer_id'], FILTER_VALIDATE_INT)){
	      $customer = new OsCustomerModel($this->params['customer']['id']);
				$old_customer_data = $customer->get_data_vars();
	      $customer->set_data($this->params['customer']);
	      if($customer->save()){
	        $response_html = __('Information Saved', 'latepoint');
	        $status = LATEPOINT_STATUS_SUCCESS;
	        do_action('latepoint_customer_updated', $customer, $old_customer_data);
	      }else{
	        $response_html = $customer->get_error_messages();
	        $status = LATEPOINT_STATUS_ERROR;
	      }
      }else{
        $response_html = __('Invalid customer ID', 'latepoint');
        $status = LATEPOINT_STATUS_ERROR;
      }
      if($this->get_return_format() == 'json'){
        $this->send_json(array('status' => $status, 'message' => $response_html));
      }
    }

    public function logout(){
      OsAuthHelper::logout_customer();
			nocache_headers();
      wp_redirect(OsSettingsHelper::get_customer_dashboard_url(), 302);
    }

    public function login(){
      $this->set_layout('none');
      return $this->format_render_return(__FUNCTION__);
    }

    public function do_login(){
      $customer = OsAuthHelper::login_customer($this->params['customer_login']['email'], $this->params['customer_login']['password']);
      if($customer){
        $response_html = OsSettingsHelper::get_customer_dashboard_url();
        $status = LATEPOINT_STATUS_SUCCESS;
      }else{
        $status = LATEPOINT_STATUS_ERROR;
        $response_html = __('Invalid password or email', 'latepoint');
      }
      if($this->get_return_format() == 'json'){
        $this->send_json(array('status' => $status, 'message' => $response_html));
      }
    }


    public function password_reset_form(){
      $this->vars['from_booking'] = (isset($this->params['from_booking']) && $this->params['from_booking']);
      $this->set_layout('none');
      return $this->format_render_return(__FUNCTION__);
    }

    public function request_password_reset_token(){
      $this->set_layout('none');
      $this->vars['from_booking'] = (isset($this->params['from_booking']) && $this->params['from_booking']);

      if(isset($this->params['password_reset_email'])){
        $customer_model = new OsCustomerModel();
        $customer = $customer_model->where(['email' => $this->params['password_reset_email']])->set_limit(1)->get_results_as_models();
        $customer_mailer = new OsCustomerMailer();
        if($customer && $customer_mailer->password_reset_request($customer, $customer->account_nonse)){
          return $this->format_render_return('password_reset_form');
        }else{
          $this->vars['reset_token_error'] = ($customer) ? __('Error! Email was not sent.', 'latepoint') : __('Email does not match any customer', 'latepoint');
          return $this->format_render_return(__FUNCTION__);
        }
      }else{
        return $this->format_render_return(__FUNCTION__);
      }
    }

    public function dashboard(){
      if(!OsAuthHelper::is_customer_logged_in()){
        $this->set_layout('none');
        return $this->format_render_return('login');
      }else{
        $customer = OsAuthHelper::get_logged_in_customer();
        $this->vars['customer'] = $customer;

				$this->vars['future_bookings'] = $customer->get_future_bookings();
				$this->vars['past_bookings'] = $customer->get_past_bookings();
				$this->vars['cancelled_bookings'] = $customer->get_cancelled_bookings();

        $this->set_layout('none');
        return $this->format_render_return(__FUNCTION__);
      }
    }

    public function change_password(){
      if(OsAuthHelper::is_customer_logged_in()){
        $customer = OsAuthHelper::get_logged_in_customer();
      }elseif($this->params['password_reset_token']){
        $customer = OsCustomerHelper::get_by_account_nonse($this->params['password_reset_token']);
        if(!$customer){
          $response_html = __('Invalid Secret Key', 'latepoint');
          $status = LATEPOINT_STATUS_ERROR;
        }
      }else{
        $status = LATEPOINT_STATUS_ERROR;
        $response_html = __('Error!', 'latepoint');
      }
      if($customer){
        if(!empty($this->params['password']) && $this->params['password'] == $this->params['password_confirmation']){
          if($customer->update_password($this->params['password'])){
            // update connected wp user password
            if(OsAuthHelper::wp_users_as_customers() && $customer->wordpress_user_id){
              global $wpdb;
              $wpdb->update(
                  $wpdb->users,
                  array(
                      'user_pass'           => $customer->password,
                      'user_activation_key' => '',
                  ),
                  array( 'ID' => $customer->wordpress_user_id )
              );
            }
            $status = LATEPOINT_STATUS_SUCCESS;
            $response_html = __('Your password was successfully updated.', 'latepoint');
          }else{
            $response_html = __('Error! Message Code: KS723J', 'latepoint');
            $status = LATEPOINT_STATUS_ERROR;
          }
        }else{
          $status = LATEPOINT_STATUS_ERROR;
          $response_html = __('Error! Passwords do not match.', 'latepoint');
        }
      }else{
        $status = LATEPOINT_STATUS_ERROR;
        $response_html = __('Customer Not Found', 'latepoint');
      }



      if($this->get_return_format() == 'json'){
        $this->send_json(array('status' => $status, 'message' => $response_html));
      }
    }

    public function set_account_password_on_booking_completion(){

      $customer = OsCustomerHelper::get_by_account_nonse($this->params['account_nonse']);

      if($customer){
        if(!empty($this->params['password'])){
          if($customer->update_password($this->params['password'])){
            $status = LATEPOINT_STATUS_SUCCESS;
            $response_html = __('Account Password Set', 'latepoint');
          }else{
            $response_html = __('Error! Message Code: KS723J', 'latepoint');
            $status = LATEPOINT_STATUS_ERROR;
          }
        }else{
          $status = LATEPOINT_STATUS_ERROR;
          $response_html = __('Error! Password is empty.', 'latepoint');
        }
      }else{
        $response_html = __('Error! Message Code: JS76SD', 'latepoint');
        $status = LATEPOINT_STATUS_ERROR;
      }


      if($this->get_return_format() == 'json'){
        $this->send_json(array('status' => $status, 'message' => $response_html));
      }
    }



  }


endif;